:py:mod:`visualiser_worker`
===========================

.. py:module:: visualiser_worker


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   visualiser_worker.initialise
   visualiser_worker.visualise
   visualiser_worker.on_end_of_life



Attributes
~~~~~~~~~~

.. autoapisummary::

   visualiser_worker.current_dir
   visualiser_worker.current_dir
   visualiser_worker.visualisation_dpg
   visualiser_worker.worker_object


.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: visualisation_dpg
   :annotation: :Heron.gui.visualisation_dpg.VisualisationDPG

   

.. py:function:: initialise(_worker_object)


.. py:function:: visualise(msg, parameters)


.. py:function:: on_end_of_life()


.. py:data:: worker_object
   

   

